summaryrefslogtreecommitdiffhomepage
path: root/test/syscalls/build_defs.bzl
diff options
context:
space:
mode:
Diffstat (limited to 'test/syscalls/build_defs.bzl')
-rw-r--r--test/syscalls/build_defs.bzl15
1 files changed, 9 insertions, 6 deletions
diff --git a/test/syscalls/build_defs.bzl b/test/syscalls/build_defs.bzl
index 6bcb7adf7..e8a66a31a 100644
--- a/test/syscalls/build_defs.bzl
+++ b/test/syscalls/build_defs.bzl
@@ -6,18 +6,22 @@ def syscall_test(test, shard_count = 5, size = "small", use_tmpfs = False):
_syscall_test(test, shard_count, size, "native", False)
_syscall_test(test, shard_count, size, "kvm", use_tmpfs)
_syscall_test(test, shard_count, size, "ptrace", use_tmpfs)
+ if not use_tmpfs:
+ _syscall_test(test, shard_count, size, "ptrace", use_tmpfs, "shared")
-def _syscall_test(test, shard_count, size, platform, use_tmpfs):
+def _syscall_test(test, shard_count, size, platform, use_tmpfs, file_access = "exclusive"):
test_name = test.split(":")[1]
# Prepend "runsc" to non-native platform names.
full_platform = platform if platform == "native" else "runsc_" + platform
name = test_name + "_" + full_platform
+ if file_access == "shared":
+ name += "_shared"
- # Add the full_platform in a tag to make it easier to run all the tests on
- # a specific platform.
- tags = [full_platform]
+ # Add the full_platform and file access in a tag to make it easier to run
+ # all the tests on a specific flavor. Use --test_tag_filters=ptrace,file_shared.
+ tags = [full_platform, "file_" + file_access]
# Add tag to prevent the tests from running in a Bazel sandbox.
# TODO: Make the tests run without this tag.
@@ -40,8 +44,7 @@ def _syscall_test(test, shard_count, size, platform, use_tmpfs):
"--test-name=" + test_name,
"--platform=" + platform,
"--use-tmpfs=" + str(use_tmpfs),
- "--debug=false",
- "--strace=false",
+ "--file-access=" + file_access,
"--parallel=true",
],
size = size,